e2e

package
v0.0.0-...-50289cb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WithCacheDir

func WithCacheDir(cacheDir string) installerOption

func WithHost

func WithHost(host string) runnerOption

func WithPort

func WithPort(port string) runnerOption

func WithSshKey

func WithSshKey(key string) runnerOption

func WithSshUser

func WithSshUser(user string) runnerOption

func WithToolkitImage

func WithToolkitImage(image string) installerOption

Types

type Runner

type Runner interface {
	Run(script string) (string, string, error)
}

func NewNestedContainerRunner

func NewNestedContainerRunner(runner Runner, baseImage string, mountToolkitFromHost bool, containerName string, cacheDir string, requiresGPUs bool) (Runner, error)

NewNestedContainerRunner creates a new nested container runner. A nested container runs a container inside another container based on a given runner (remote or local).

func NewRunner

func NewRunner(opts ...runnerOption) Runner

type ToolkitInstaller

type ToolkitInstaller struct {
	ToolkitImage string
	CacheDir     string
}

func NewToolkitInstaller

func NewToolkitInstaller(opts ...installerOption) (*ToolkitInstaller, error)

func (*ToolkitInstaller) Install

func (i *ToolkitInstaller) Install(runner Runner) (string, string, error)

func (*ToolkitInstaller) PrepareCache

func (i *ToolkitInstaller) PrepareCache(runner Runner) (string, string, error)

PrepareCache ensures that the installer (package) cache is created on the runner. The can be used to ensure that docker is not REQUIRED in an inner container.

Jump to